@@ -1,7 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 /* Author: Jaka Mocnik <jaka.mocnik@kiss.uni-lj.si>
- * Integrated with keyboard bell applet by Justin Maurer <justin@helixcode.com>
- * (C) 2000 Helix Code, Inc.
  * Based on gnome-core/desktop-properties/property-keyboard.c
  */
 #include <config.h>
@@ -29,17 +27,9 @@ static GtkWidget *capplet;
 static GtkWidget *rbutton, *cbutton, *rscale, *dscale, *vscale;
 static GtkObject *vol_adjust, *rate_adjust, *del_adjust;
 
-static gint bell_percent;
-static gint bell_pitch;
-static gint bell_duration;
-static GtkObject *vadj, *padj, *dadj;
-static GtkWidget *vscale, *pscale, *dscale;
-
 #ifdef HAVE_X11_EXTENSIONS_XF86MISC_H
 static XF86MiscKbdSettings kbdsettings;
 #endif
-static void bell_revert(void);
-static void bell_write(void);
 
 static void
 keyboard_read(void)
@@ -87,7 +77,7 @@ keyboard_help(void)
 {
   gchar *tmp;
 
-  tmp = gnome_help_file_find_file ("control-center", "peripherals.html#GCCKEY");
+  tmp = gnome_help_file_find_file ("users-guide", "gccperiph.html#GCCKEY");
   if (tmp) {
           gnome_help_goto(0, tmp);
           g_free(tmp);
@@ -105,8 +95,8 @@ static void
 keyboard_apply(void)
 {
         int event_base_return, error_base_return;
-
-	if (keyboard_repeat) {
+        
+        if (keyboard_repeat) {
 		XAutoRepeatOn(GDK_DISPLAY());
 #ifdef HAVE_X11_EXTENSIONS_XF86MISC_H
 		if (XF86MiscQueryExtension(GDK_DISPLAY(), &event_base_return, &error_base_return) == True) {
@@ -128,7 +118,6 @@ keyboard_apply(void)
 static void
 keyboard_write(void)
 {
-        bell_write ();
         keyboard_apply();
 	gnome_config_set_bool("/Desktop/Keyboard/repeat", keyboard_repeat);
 	gnome_config_set_int("/Desktop/Keyboard/delay", keyboard_delay);
@@ -141,7 +130,6 @@ keyboard_write(void)
 static void
 keyboard_revert (void)
 {
-        bell_revert ();
         keyboard_read();
         keyboard_apply();
         GTK_ADJUSTMENT (vol_adjust)->value = click_volume;
@@ -209,6 +197,7 @@ make_scale (char *title, GtkObject *adjust, int *update_var, GtkWidget *table, i
                           GTK_FILL | GTK_SHRINK,
                           GTK_FILL | GTK_SHRINK,
                           0, 0);
+        gtk_widget_show (ttl);
 
         scale = gtk_hscale_new (GTK_ADJUSTMENT (adjust));
         gtk_range_set_update_policy (GTK_RANGE (scale), GTK_UPDATE_CONTINUOUS);
@@ -222,96 +211,30 @@ make_scale (char *title, GtkObject *adjust, int *update_var, GtkWidget *table, i
                           GTK_EXPAND | GTK_FILL | GTK_SHRINK,
                           GTK_FILL | GTK_SHRINK,
                           0, 0);
+        gtk_widget_show (scale);
 
         return scale;
 }
 
-static void
-bell_test(GtkWidget *widget, void *data)
-{
-        gint save_percent;
-        gint save_pitch;
-        gint save_duration;
-
-        XGetKeyboardControl(GDK_DISPLAY(), &kbdstate);
-
-        save_percent = kbdstate.bell_percent;
-        save_pitch = kbdstate.bell_pitch;
-        save_duration = kbdstate.bell_duration;
-
-        kbdcontrol.bell_percent = bell_percent;
-        kbdcontrol.bell_pitch = bell_pitch;
-        kbdcontrol.bell_duration = bell_duration;
-        XChangeKeyboardControl(GDK_DISPLAY(), KBBellPercent | KBBellPitch | KBBellDuration, &kbdcontrol);
-
-        XBell (gdk_display,0);
-
-        kbdcontrol.bell_percent = save_percent;
-        kbdcontrol.bell_pitch = save_pitch;
-        kbdcontrol.bell_duration = save_duration;
-        XChangeKeyboardControl(GDK_DISPLAY(), KBBellPercent | KBBellPitch | KBBellDuration, &kbdcontrol);
-}
-
-static GtkWidget *
-bell_setup(void)
-{
-        GtkWidget *frame;
-        GtkWidget *table;
-        GtkWidget *test, *hbox, *inner_hbox, *volume;
-
-        frame = gtk_frame_new(_("Keyboard bell"));
-        table = gtk_table_new (4, 2, FALSE);
-        gtk_container_set_border_width (GTK_CONTAINER (table), GNOME_PAD_SMALL);
-        gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
-        gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
-        gtk_container_add (GTK_CONTAINER (frame), table);
-
-        vadj = gtk_adjustment_new(bell_percent, 0, 100, 1, 1, 0);
-        vscale = make_scale(_("Volume"), vadj, &bell_percent, table, 1);
-
-        padj = gtk_adjustment_new(bell_pitch, 0, 2000, 1, 1, 0);
-        pscale = make_scale (_("Pitch (Hz)"), padj, &bell_pitch, table, 2);
-
-        dadj = gtk_adjustment_new(bell_duration, 0, 500, 1, 1, 0);
-        dscale = make_scale(_("Duration (ms)"), dadj, &bell_duration, table, 3);        /* Finished */
-
-        test = gtk_button_new ();
-        hbox = gtk_hbox_new (FALSE, 0);
-        gtk_box_pack_start (GTK_BOX (hbox), test, FALSE, FALSE, 0);
-        gtk_table_attach_defaults (GTK_TABLE(table), hbox, 0, 2, 4, 5);
-
-        gtk_signal_connect (GTK_OBJECT (test), "clicked",
-                            GTK_SIGNAL_FUNC (bell_test), NULL);
-        inner_hbox = gtk_hbox_new (FALSE, 0);
-        volume = gnome_stock_pixmap_widget (test, GNOME_STOCK_PIXMAP_VOLUME);
-        gtk_box_pack_start (GTK_BOX (inner_hbox), volume, FALSE, FALSE, 0);
-        gtk_box_pack_start (GTK_BOX (inner_hbox), gtk_label_new (_("Test")), FALSE, FALSE, 8);
-        gtk_container_add (GTK_CONTAINER (test), inner_hbox);
-
-        return frame;
-}
-
-
 static void
 keyboard_setup (void)
 {
-        GtkWidget *vbox;
-        GtkWidget *frame, *table, *bell;
-#if 0
-        GtkWidget *label, *entry, *hbox;
-#endif
+        GtkWidget *vbox, *frame, *table, *hbox, *label, *entry, *wtmp;
+
         vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
+        gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
 
         capplet = capplet_widget_new();
-        frame = gtk_frame_new (_("Keyboard repeat rate"));
+        frame = gtk_frame_new (_("Auto-repeat"));
         gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
+        gtk_widget_show (frame);
 
-        table = gtk_table_new (4, 2, FALSE);
+        table = gtk_table_new (3, 2, FALSE);
         gtk_container_set_border_width (GTK_CONTAINER (table), GNOME_PAD_SMALL);
         gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
         gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
         gtk_container_add (GTK_CONTAINER (frame), table);
-
+        gtk_widget_show (table);
 
         rbutton = gtk_check_button_new_with_label (_("Enable auto-repeat"));
         gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(rbutton), keyboard_repeat);
@@ -320,6 +243,7 @@ keyboard_setup (void)
                           GTK_FILL | GTK_SHRINK,
                           GTK_FILL | GTK_SHRINK,
                           0, 0);
+        gtk_widget_show (rbutton);
 
         rate_adjust = gtk_adjustment_new (keyboard_rate, 0, 255, 1, 1, 0);
         rscale = make_scale (_("Repeat rate"), rate_adjust, &keyboard_rate, table, 1);
@@ -329,12 +253,14 @@ keyboard_setup (void)
 
         frame = gtk_frame_new (_("Keyboard click"));
         gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
+        gtk_widget_show (frame);
+
         table = gtk_table_new (2, 2, FALSE);
-        gtk_container_add (GTK_CONTAINER (frame), table);
         gtk_container_set_border_width (GTK_CONTAINER (table), GNOME_PAD_SMALL);
         gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
         gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
-
+        gtk_container_add (GTK_CONTAINER (frame), table);
+        gtk_widget_show (table);
 
         cbutton = gtk_check_button_new_with_label (_("Click on keypress"));
         gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(cbutton), click_on_keypress);
@@ -343,26 +269,28 @@ keyboard_setup (void)
                           GTK_FILL | GTK_SHRINK,
                           GTK_FILL | GTK_SHRINK,
                           0, 0);
+        gtk_widget_show (cbutton);
 
         vol_adjust = gtk_adjustment_new (click_volume, 0, 100, 1, 1, 0);
         vscale = make_scale (_("Click volume"), vol_adjust, &click_volume, table, 1);
 
-	bell = bell_setup ();
-        gtk_box_pack_start (GTK_BOX (vbox), bell, FALSE, FALSE, 0);
-
-#if 0        
-        frame = gtk_frame_new(_("Preview"));
-        gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
+        wtmp = gtk_frame_new(_("Preview"));
+        gtk_widget_show(wtmp);
+        gtk_box_pack_start(GTK_BOX (vbox), wtmp, FALSE, FALSE, 0);
         hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
-        gtk_container_add(GTK_CONTAINER(frame), hbox);
+        gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
+        gtk_container_add(GTK_CONTAINER(wtmp), hbox);
+        gtk_widget_show(hbox);
 
         label = gtk_label_new(_("Test settings"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_box_pack_start(GTK_BOX (hbox), label, FALSE, FALSE, 0);
+        gtk_widget_show(label);
 
         entry = gtk_entry_new();
         gtk_box_pack_start(GTK_BOX (hbox), entry, TRUE, TRUE, 0);
-#endif
+        gtk_widget_show(entry);
+
         gtk_signal_connect (GTK_OBJECT (capplet), "help",
                             GTK_SIGNAL_FUNC (keyboard_help), NULL);
         gtk_signal_connect (GTK_OBJECT (capplet), "try",
@@ -376,78 +304,12 @@ keyboard_setup (void)
         gtk_signal_connect (GTK_OBJECT (rbutton), "clicked",
                             GTK_SIGNAL_FUNC (button_toggled), NULL);
 
-        gtk_widget_show_all (vbox);
+        gtk_widget_show (vbox);
         gtk_container_add (GTK_CONTAINER (capplet), vbox);
         gtk_widget_show (capplet);
 }
 
-static void bell_read(void)
-{
-        bell_percent = gnome_config_get_int("/Desktop/Bell/percent=-1");
-        bell_pitch = gnome_config_get_int("/Desktop/Bell/pitch=-1");
-        bell_duration = gnome_config_get_int("/Desktop/Bell/duration=-1");
 
-        XGetKeyboardControl(GDK_DISPLAY(), &kbdstate);
-
-        if (bell_percent == -1) {
-                bell_percent = kbdstate.bell_percent;
-        }
-        if (bell_pitch == -1) {
-                bell_pitch = kbdstate.bell_pitch;
-        }
-        if (bell_duration == -1) {
-                bell_duration = kbdstate.bell_duration;
-        }
-}
-
-static void bell_apply(void)
-{
-        kbdcontrol.bell_percent = bell_percent;
-        kbdcontrol.bell_pitch = bell_pitch;
-        kbdcontrol.bell_duration = bell_duration;
-        XChangeKeyboardControl(GDK_DISPLAY(), KBBellPercent | KBBellPitch | KBBellDuration, &kbdcontrol);
-}
-
-static void bell_help(void)
-{
-  gchar *tmp;
-
-  tmp = gnome_help_file_find_file ("users-guide", "gccmm.html#GCC-KEYBELL");
-  if (tmp) {
-    gnome_help_goto(0, tmp);
-    g_free(tmp);
-  } else {
-          GtkWidget *mbox;
-
-          mbox = gnome_message_box_new(_("No help is available/installed for these settings. Please make sure you\nhave the GNOME User's Guide installed on your system."),
-                                       GNOME_MESSAGE_BOX_ERROR,
-                                       _("Close"), NULL);
-
-          gtk_widget_show(mbox);
-  }
-}
-
-static void bell_write(void)
-{
-        bell_apply();
-        gnome_config_set_int("/Desktop/Bell/percent", bell_percent);
-        gnome_config_set_int("/Desktop/Bell/pitch", bell_pitch);
-        gnome_config_set_int("/Desktop/Bell/duration", bell_duration);
-        gnome_config_sync ();
-}
-
-static void
-bell_revert (void)
-{
-        bell_read();
-        bell_apply();
-        GTK_ADJUSTMENT (vadj)->value = bell_percent;
-        GTK_ADJUSTMENT (padj)->value = bell_pitch;
-        GTK_ADJUSTMENT (dadj)->value = bell_duration;
-        gtk_adjustment_changed (GTK_ADJUSTMENT (vadj));
-        gtk_adjustment_changed (GTK_ADJUSTMENT (padj));
-        gtk_adjustment_changed (GTK_ADJUSTMENT (dadj));
-}
 
 int
 main (int argc, char **argv)
@@ -495,12 +357,10 @@ main (int argc, char **argv)
 		token = 1;
 
         keyboard_read ();	
-	bell_read ();
 
-        if (token) {
+        if(token) 
                 keyboard_apply ();
-		bell_apply ();
-        }
+
 	if (init_results != 1) {
 		keyboard_setup ();
 	        capplet_gtk_main ();
